"""This submodule provides the necessary objects for parameter estimation using only a cost function
without explicit data and model. Because of this kafe2 Plots are not available, though plots of the
parameter profiles and contours can still be created.

:synopsis: This submodule provides the necessary objects for parameter estimation using only a cost
function without explicit data and model.

.. moduleauthor:: Johannes Gäßler <johannes.gaessler@cern.ch>
"""

# flake8: noqa F401, F403 (imported but unused, used but unable to detect undefined names)

from .fit import *
